pub fn payload_id(
parent: &FixedBytes<32>,
attributes: &PayloadAttributes,
) -> PayloadIdAvailable on crate feature
node-api only.Expand description
Generates the payload id for the configured payload from the PayloadAttributes.
Returns an 8-byte identifier by hashing the payload components with sha256 hash.